@@ -105,7 +105,7 @@ def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = No
             level=level,
             format="[%(asctime)s] %(levelname)s - %(message)s",
             datefmt="%H:%M:%S",
-            # handlers=[console_handler],
+            handlers=[console_handler],
         )
 
 
